pub struct PostSchedulingFn(pub Arc<dyn Fn(&Card, f32, usize, &[usize], &mut StdRng) -> f32 + Sync + Send>);Expand description
Function type for post scheduling operations that takes interval, maximum interval, current day index, due counts per day, and a random number generator, and returns a new interval.
Tuple Fields
0: Arc<dyn Fn(&Card, f32, usize, &[usize], &mut StdRng) -> f32 + Sync + Send>Trait Implementations
Sourceimpl Debug for PostSchedulingFn
impl Debug for PostSchedulingFn
Sourceimpl PartialEq for PostSchedulingFn
impl PartialEq for PostSchedulingFn